#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-


# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
# for more details.
#
# If you have not received a copy of the GNU General Public License along
# with this program, see <https://www.gnu.org/licenses/>.


# part of mkp package "powerscale"
# see ~/local/share/doc/check_mk/powerscale for maintainer and information


#
from cmk.gui.plugins.wato import (
    HostRulespec,
    IndividualOrStoredPassword,
    monitoring_macro_help,
    RulespecGroup,
    rulespec_group_registry,
    rulespec_registry,
)

#
from cmk.gui.valuespec import (
    Dictionary,
    TextInput,
    DropdownChoice,
    Integer,
    ListChoice,
)


#
from cmk.gui.plugins.wato.datasource_programs import RulespecGroupDatasourceProgramsHardware

#
def _valuespec_special_agent_powerscale():
    return Dictionary(
        title = _("Dell PowerScale"),
        help  = _("This rule activates an agent that collects information from "
                  "Dell PowerScale systems."),

        optional_keys = [],

        elements = [
            ( "user",
                TextInput(
                    title       = _("Username"),
                    allow_empty = False,
                    help        = _("Need <tt>ISI_PRIV_LOGIN_PAPI</tt> for API login. "
                                    "See <tt>~/local/share/doc/check_mk/powerscale</tt>"),
                ),
            ),
            ( "password",
                Password(
                    title       = _("Password"),
                    allow_empty = False,
                )
            ),
            ( "nossl",
               DropdownChoice(
                   title   = _("Type of query"),
                   choices = [
                       ( False, _("Use SSL (Default)" ) ),
                       ( True,  _("Do not use SSL to connect to API") ),
                   ],
                   default_value = False,
               )
            ),
            ( "connect",
               Integer(
                    title         = _("TCP port number"),
                    help          = _("Port number for connection to API. Usually 8080"),
                    default_value = 8080,
                    minvalue      = 1,
                    maxvalue      = 65535,
               )
            ),
            ( "infos",
                Transform(
                    ListChoice(
                        choices = [
                            ( "events",    _("Events and Alerts")),
                            ( "nodes",     _("Node Hardware")),
                            ( "system",    _("System Statistics")),
                            ( "quotas",    _("SmartQuotas")),
                            ( "synciq",    _("SyncIQ")),
                        ],
                        default_value = [ "events", "nodes", "system" ],
                        help        = _("Need several privileges. "
                                        "See <tt>~/local/share/doc/check_mk/powerscale</tt>"),
                        allow_empty   = False,
                     ),
                title = _("Retrieve information about..."),
                )
            ),
            ( "summary",
               DropdownChoice(
                   title   = _("Service Discovery"),
                   choices = [
                       ( True,  _("Show Summary (Default)" ) ),
                       ( False, _("Show Single Services") ),
                   ],
                   default_value = True,
               )
            ),
        ],
    )


#
rulespec_registry.register(
    HostRulespec(
        group=RulespecGroupDatasourceProgramsHardware,
        name="special_agents:powerscale",
        valuespec=_valuespec_special_agent_powerscale,
    ))
